@@ -48,7 +48,7 @@ JImage::JImage(JImage &img)
 }
 
 // Carga la imagen desde fichero. Soporta '.tga', '.bmp', '.jpg' y otros
-bool JImage::Load(const JString &filename, bool toDisplayFormat, u32 cKey)
+bool JImage::Load(const char *filename, bool toDisplayFormat, u32 cKey)
 {
   surface = IMG_Load(filename);
   if (surface != 0)
@@ -242,89 +242,35 @@ void JImage::PutPixel(s32 x, s32 y, u32 color)
 }
 
 // Guarda la imagen como BMP
-bool JImage::SaveAsBMP(const JString &file)
+bool JImage::SaveAsBMP(const char *file)
 {
   return (0 == SDL_SaveBMP(surface, file));
 }
 
 // Carga la imagen.
-u32 JImage::Load(JFile &f)
+u32 JImage::Load(JRW &f)
 {
 	Destroy();
 
   s32 w, h;
   u32 ckey, sz, Rmask, Gmask, Bmask, Amask;
   u8 bpp, *data;
-  if (f.ReadLE32(&w) &&
-      f.ReadLE32(&h) &&
-      f.Read(&bpp, 1) &&
-			f.ReadLE32(&Rmask) &&
-			f.ReadLE32(&Gmask) &&
-			f.ReadLE32(&Bmask) &&
-			f.ReadLE32(&Amask) &&
-      f.ReadLE32(&ckey) &&
-      f.ReadLE32(&sz))
+  if (f.ReadLE32(&w) && f.ReadLE32(&h) && f.Read8(&bpp) &&
+      f.ReadLE32(&Rmask) && f.ReadLE32(&Gmask) && f.ReadLE32(&Bmask) &&
+      f.ReadLE32(&Amask) && f.ReadLE32(&ckey) && f.ReadLE32(&sz))
   {
     data = new u8[sz];
-		
-		int count;
-		
-		switch (bpp)
-		{
-		case 8:
-			if (f.Read(data, sz))
-			{
-				if (Create(w, h, bpp, data, Rmask, Gmask, Bmask, Amask))
-				{
-					ColorKey(ckey);
-					
-					delete[] data;
-					
-					return 0;
-				}
-			}
-			break;
-			
-		case 16:
-			for (s32 i = 0; i < sz; i += 2)
-			{
-				if (!f.ReadLE16(&data[i]))
-				{
-					delete[] data;
-					return 2;
-				}
-			}
-			
-			if (Create(w, h, bpp, data, Rmask, Gmask, Bmask, Amask))
-			{
-				ColorKey(ckey);
-				
-				delete[] data;
-				
-				return 0;
-			}
-			break;			
+    if (f.Read(data, sz))
+    {
+      if (Create(w, h, bpp, data, Rmask, Gmask, Bmask, Amask))
+      {
+        ColorKey(ckey);
 
-		case 32:
-			for (s32 i = 0; i < sz; i += 4)
-			{
-				if (!f.ReadLE32(&data[i]))
-				{
-					delete[] data;
-					return 3;
-				}
-			}
-			
-			if (Create(w, h, bpp, data, Rmask, Gmask, Bmask, Amask))
-			{
-				ColorKey(ckey);
-				
 				delete[] data;
-				
-				return 0;
-			}
-			break;			
-		}
+
+        return 0;
+      }
+    }
 
 		delete[] data;
   }
@@ -333,12 +279,12 @@ u32 JImage::Load(JFile &f)
 }
 
 // Salva la imagen.
-u32 JImage::Save(JFile &f)
+u32 JImage::Save(JRW &f)
 {
   u32 sz = Size();
   if (f.WriteLE32(&surface->w) &&
       f.WriteLE32(&surface->h) &&
-      f.Write(&surface->format->BitsPerPixel, 1) &&
+      f.Write8(&surface->format->BitsPerPixel) &&
       f.WriteLE32(&surface->format->Rmask) &&
       f.WriteLE32(&surface->format->Gmask) &&
       f.WriteLE32(&surface->format->Bmask) &&
@@ -348,64 +294,19 @@ u32 JImage::Save(JFile &f)
   {
     if (0 == Lock())
     {
-			u8 *data;
-			s32 W = surface->w * BytesPP();
-
-			switch (surface->format->BitsPerPixel)
+			// Salva cada lnea, pues hemos de tener en cuenta el pitch en memoria
+			for (s32 j = 0; j < surface->h; ++j)
 			{
-			default:
-			case 8:
-				// Salva cada lnea, pues hemos de tener en cuenta el pitch en memoria
-				for (s32 j = 0; j < surface->h; ++j)
+				u8 *data = Line(j);
+				if (0 == f.Write(data, surface->w * BytesPP()))
 				{
-					data = Line(j);
-					if (0 == f.Write(data, W))
-					{
-						// Error E/S
-						Unlock();
-						return 1;
-					}
+					// Error E/S
+					Unlock();
+					return 1;
 				}
-				break;
-
-			case 16:
-				// Salva cada lnea, pues hemos de tener en cuenta el pitch en memoria
-				for (s32 j = 0; j < surface->h; ++j)
-				{
-					data = Line(j);
-					
-					for (s32 i = 0; i < W; i += 2)
-					{
-						if (0 == f.WriteLE16(&data[i]))
-						{
-							// Error E/S
-							Unlock();
-							return 1;
-						}
-					}
-				}
-				break;
-
-			case 32:
-				// Salva cada lnea, pues hemos de tener en cuenta el pitch en memoria
-				for (s32 j = 0; j < surface->h; ++j)
-				{
-					data = Line(j);
-					
-					for (s32 i = 0; i < W; i += 4)
-					{
-						if (0 == f.WriteLE32(&data[i]))
-						{
-							// Error E/S
-							Unlock();
-							return 1;
-						}
-					}
-				}
-				break;
 			}
-      
-			Unlock();
+
+      Unlock();
       
       return 0;
     }
@@ -414,6 +315,18 @@ u32 JImage::Save(JFile &f)
   return 2;
 }
 
+u32 JImage::LoadImage(JRW &jrw)
+{
+	Destroy();
+
+  if (0 == (surface = IMG_Load_RW(jrw.rwops, 0)))
+  {
+    return 1; 
+  }
+  
+  return 0;
+}
+
 JImage * JImage::Scale(float xp, float yp)
 {
 	if (-1 == Lock())
@@ -422,13 +335,10 @@ JImage * JImage::Scale(float xp, float yp)
 	}
 
 	s32 newW = (s32)(surface->w * xp), newH = (s32)(surface->h * yp);
-	s32 w = surface->w, h = surface->h;
 	
 	float dx = 1.0f/xp, dy = 1.0f/yp;                // Tamao de 1 pixel original en coordenadas de la nueva imagen
 	
 
-	float sNew = 1.0f/(xp * yp);                     // Superficie de un punto de la nueva imagen en coordenadas de la imagen original
-	float sOrg = xp * yp;                            // Superficie de un punto de la imagen original en coordenadas de la imagen nueva
 	SDL_Color samp;                                  // Muestra actual
 
 	JImage *img = new JImage(newW, newH, surface->format->BitsPerPixel);
@@ -546,3 +456,56 @@ bool JImage::Convert(SDL_PixelFormat *fmt, u32 flags)
 	
 	return false;
 }
+
+JString JImage::DumpFromSurface(SDL_Surface *s)
+{
+	JString s1, s2, s3, s4, s5, s6;
+	SDL_PixelFormat *fmt = s->format;
+
+	s1.Format("%dx%d@%d COLOR_KEY: %08x SURFACE_ALPHA: %d\n", s->w, s->h, fmt->BitsPerPixel, fmt->colorkey, fmt->alpha);
+	s2.Format("pitch: %d clip_rect: x%d y%d w%d h%d pixels: %p\n", s->pitch, s->clip_rect.x, s->clip_rect.y, s->clip_rect.w, s->clip_rect.h, s->pixels);
+	s3.Format("RGBAmask: R: 0x%08x G: 0x%08x B: 0x%08x A: 0x%08x\n", fmt->Rmask, fmt->Gmask, fmt->Bmask, fmt->Amask);
+	s4.Format("RGBAshift: R: 0x%08x G: 0x%08x B: 0x%08x A: 0x%08x\n", fmt->Rshift, fmt->Gshift, fmt->Bshift, fmt->Ashift);
+	s5.Format("RGBAloss: R: 0x%08x G: 0x%08x B: 0x%08x A: 0x%08x\n", fmt->Rloss, fmt->Gloss, fmt->Bloss, fmt->Aloss);
+	s6.Format("Flags:\n"
+						"SDL_SWSURFACE: %s\n" 
+						"SDL_HWSURFACE: %s\n" 
+						"SDL_ASYNCBLIT: %s\n" 
+						"SDL_ANYFORMAT: %s\n" 
+						"SDL_HWPALETTE: %s\n" 
+						"SDL_DOUBLEBUF: %s\n" 
+						"SDL_FULLSCREEN: %s\n" 
+						"SDL_OPENGL: %s\n" 
+						"SDL_OPENGLBLIT: %s\n" 
+						"SDL_RESIZABLE: %s\n" 
+						"SDL_HWACCEL: %s\n" 
+						"SDL_SRCCOLORKEY: %s\n" 
+						"SDL_RLEACCEL: %s\n" 
+						"SDL_SRCALPHA: %s\n" 
+						"SDL_PREALLOC: %s\n",
+						(s->flags & SDL_SWSURFACE) ? "yes" : "no", 
+						(s->flags & SDL_HWSURFACE) ? "yes" : "no", 
+						(s->flags & SDL_ASYNCBLIT) ? "yes" : "no", 
+						(s->flags & SDL_ANYFORMAT) ? "yes" : "no", 
+						(s->flags & SDL_HWPALETTE) ? "yes" : "no", 
+						(s->flags & SDL_DOUBLEBUF) ? "yes" : "no", 
+						(s->flags & SDL_FULLSCREEN) ? "yes" : "no", 
+						(s->flags & SDL_OPENGL) ? "yes" : "no", 
+						(s->flags & SDL_OPENGLBLIT) ? "yes" : "no", 
+						(s->flags & SDL_RESIZABLE) ? "yes" : "no", 
+						(s->flags & SDL_HWACCEL) ? "yes" : "no", 
+						(s->flags & SDL_SRCCOLORKEY) ? "yes" : "no", 
+						(s->flags & SDL_RLEACCEL) ? "yes" : "no", 
+						(s->flags & SDL_SRCALPHA) ? "yes" : "no", 
+						(s->flags & SDL_PREALLOC) ? "yes" : "no");
+	
+	JString str;
+	str += s1;
+	str += s2;
+	str += s3;
+	str += s4;
+	str += s5;
+	str += s6;
+	
+	return str;
+}
