@@ -34,9 +34,9 @@
 #endif
 
 HCLevel::HCLevel()  : numEnemies(0), enemies(0), numRopes(0), 
-											ropes(0), numObjects(0), objects(0),
-											remainingObjects(0), scripted(false), narrative(0), 
-											timerFont(0), maxTime(1)
+											ropes(0), remainingObjects(0), numObjects(0), objects(0),
+											scripted(false), narrative(0), wideMap(false), highMap(false),
+											maxTime(1), timerFont(0)
 {
 }
 
@@ -323,20 +323,20 @@ void HCLevel::Draw()
 		levelTimer.Draw();
 
 		// Draws the remaining objects to complete the level
-		s32 qw = JApp::App()->Width()/4, dx = qw/(numObjects + 1);
+		float qw = float(JApp::App()->Width())/4.0f, dx = qw/float(numObjects + 1);
 		for (i = 0; i < numObjects; ++i)
 		{
 			objects[i]->Draw();
 			
 			if (objects[i]->State() == HCOBJECTSTATE_NORMAL)
 			{
-				((JImage *)objects[i]->Normal().Frame(0))->Draw(qw * 3 + dx * i, 0);
+				((JImage *)objects[i]->Normal().Frame(0))->Draw(s32(qw * 3.0f + dx * float(i)), 0);
 			}
 		}
 	}
 }
 
-u32 HCLevel::Load(JFile &file)
+u32 HCLevel::Load(JRW &file, const char *filename)
 {
 	Destroy();
 
@@ -406,8 +406,11 @@ u32 HCLevel::Load(JFile &file)
 
 		for (s32 i = 0; i < numEnemies; ++i)
 		{
-			if (0 != file.Peep(&enemyType, sizeof(enemyType)))
+			if (0 != file.ReadLE32((s32 *)&enemyType))
 			{
+        // Lets the file at ist original position
+        file.Seek(-4, SEEK_CUR);
+
 				// Peeps the type of enemy
 				switch (enemyType)
 				{
@@ -506,7 +509,7 @@ u32 HCLevel::Load(JFile &file)
 	}
 
 	// Checks if a background named as the file and ended in '.tga' exists
-	str.Format("%s.tga", file.Name());
+	str.Format("%s.tga", filename);
 	
 	if (JFile::Exists(str))
 	{
@@ -582,7 +585,7 @@ u32 HCLevel::Load(JFile &file)
 	return 0;
 }
 
-u32 HCLevel::Save(JFile &file)
+u32 HCLevel::Save(JRW &file)
 {
 	s32 x, y;
 
@@ -697,7 +700,7 @@ u32 HCLevel::Save(JFile &file)
 
 void HCLevel::Pos(float xPos, float yPos)
 {
-	float wMax, hMax, wMap, hMap, xMap, yMap, xBg, yBg, dx, dy;
+	float xMap, yMap, xBg, yBg, dx, dy;
 	float xMapOrg = map.X();
 	float yMapOrg = map.Y();
 
