@@ -31,6 +31,7 @@
 #define _HOLOTZ_INCLUDED
 
 #include <JLib/Util/JApp.h>
+#include <JLib/Util/JTypes.h>
 #include <JLib/Graphics/JTextMenu.h>
 #include <HCLevel.h>
 #include <HCScript.h>
@@ -58,15 +59,18 @@ class HCEnemyChaser;
 "Carlos & Vero & Álvaro, Edu & Vero,\n"\
 "Alex, Chily, Santos & Rocío, Felix &\n"\
 "Carmen, Ossuna's, Jose & Gloria, Ori &\n"\
-"Loli, Diana & David, Luis, Angel,\n"\
-"Celia, Iñigo, Markus Rath (German translation),\n"\
+"Loli, Diana & David, Luis,\n"\
+"Angel, Celia, Iñigo,\n"\
+"Markus Rath/Ronny Standtke (German translation),\n"\
 "Milan Babuškov (Add-on levels),\n"\
 "Miriam Ruiz (Debian package),\n"\
 "Nicolas Elie (French translation),\n"\
 "Вячеслав Диконов \n(Vyacheslav Dikonov - Russian translation),\n"\
 "3ARRANO Euskalgintza (Euskara translation),\n"\
 "Andreas Jochens (AMD64 Patches),\n"\
-"Maksim Mokriyev (Ukranian translation)"
+"Maksim Mokriyev (Ukranian translation)\n"\
+"Filip (Triple T) Bártek (Czech translation)\n"\
+"Pierre-Paul Lavoie (FreeBSD porting)"
 
 /** Possible states of the game.
  */
@@ -157,9 +161,11 @@ class HCApp : public JApp
 	JImage *imgBack;                      /**< Image for background storing. */
 	HCText *textBack;                     /**< General purpouse text message. */
 	JImage *imgHelp;                      /**< Help text message. */
-
+	
 	HCLoadSaveSlot saveData[HC_NUM_SLOTS];/**< Slots for loading and saving. */
 
+	bool stateChanged;                    /**< App state change flag */
+
 	/** Initializes the menu state.
 	 * @return <b>true</b> if initialization succeeded, <b>false</b> if not.
 	 */
@@ -399,6 +405,10 @@ class HCApp : public JApp
 	 */
 	static void OnKeyDown(SDL_keysym key);
 
+	/** Process the state change of the app.
+	 */
+	void ProcessStateChange();
+
  public:
 	/** Creates the application object.
 	 */
@@ -426,8 +436,8 @@ class HCApp : public JApp
 	 */
 	inline HCState State();
 
-	/** Returns the state of the app.
-	 * @return State of the app.
+	/** Changes the state of the app.
+	 * @param  newState New state of the app.
 	 */
 	void State(HCState newState);
 
